Fairness Service
================

A service to enforce a fair resource utilization in a OpenStack infrastructure
by automatic and dynamic reallocation of the resources (cpu, mem, disk, network)
during runtime.

----

Run the controller_manager.py on the OpenStack Controller and the node_manager
on all OpenStack Compute nodes.

more info follows...